You are receiving this mail as a port that you maintain
is failing to build on the FreeBSD package build server.
Please investigate the failure and submit a PR to fix
build.

Maintainer:     [email protected]
Log URL:        
https://pkg-status.freebsd.org/beefy22/data/144amd64-default/ce97aa4dd1d9/logs/rustls-ffi-0.15.5.log
Build URL:      
https://pkg-status.freebsd.org/beefy22/build.html?mastername=144amd64-default&build=ce97aa4dd1d9
Log:

=>> Building security/rustls-ffi
build started at Tue Oct 20 10:55:35 UTC 2026
port directory: /usr/ports/security/rustls-ffi
package name: rustls-ffi-0.15.5
building for: FreeBSD 144amd64-default-job-33 14.4-RELEASE-p11 FreeBSD 
14.4-RELEASE-p11 amd64
maintained by: [email protected]
Makefile datestamp: -rw-r--r--  1 root wheel 782 Oct 20 01:01 
/usr/ports/security/rustls-ffi/Makefile
Ports top last git commit: ce97aa4dd1d9326775655b810ef384f38f78f0e5
Ports top unclean checkout: no
Port dir last git commit: 08f51f9b6492b69c07ea2e068083214eaccda34e
Port dir unclean checkout: no
Poudriere version: poudriere-git-3.4.8-3-gd92fb7c0
Host OSVERSION: 1600022
Jail OSVERSION: 1404000
Job Id: 33

---Begin Environment---
SHELL=/bin/sh
OSVERSION=1404000
UNAME_v=FreeBSD 14.4-RELEASE-p11
UNAME_r=14.4-RELEASE-p11
BLOCKSIZE=K
MAIL=/var/mail/root
MM_CHARSET=UTF-8
LANG=C.UTF-8
STATUS=1
HOME=/root
PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
MAKE_OBJDIR_CHECK_WRITABLE=0
LOCALBASE=/usr/local
USER=root
POUDRIERE_NAME=poudriere-git
LIBEXECPREFIX=/usr/local/libexec/poudriere
POUDRIERE_VERSION=3.4.8-3-gd92fb7c0
MASTERMNT=/usr/local/poudriere/data/.m/144amd64-default/ref
LC_COLLATE=C
POUDRIERE_BUILD_TYPE=bulk
PACKAGE_BUILDING=yes
SAVED_TERM=
OUTPUT_REDIRECTED_STDERR=4
OUTPUT_REDIRECTED=1
PWD=/usr/local/poudriere/data/.m/144amd64-default/33/.p
OUTPUT_REDIRECTED_STDOUT=3
P_PORTS_FEATURES=FLAVORS SUBPACKAGES SELECTED_OPTIONS
MASTERNAME=144amd64-default
SCRIPTPREFIX=/usr/local/share/poudriere
SCRIPTNAME=bulk.sh
OLDPWD=/usr/local/poudriere/data/.m/144amd64-default/ref/.p/pool
POUDRIERE_PKGNAME=poudriere-git-3.4.8-3-gd92fb7c0
SCRIPTPATH=/usr/local/share/poudriere/bulk.sh
POUDRIEREPATH=/usr/local/bin/poudriere
---End Environment---

---Begin Poudriere Port Flags/Env---
PORT_FLAGS=
PKGENV=
FLAVOR=
MAKE_ARGS=
---End Poudriere Port Flags/Env---

---Begin OPTIONS List---
---End OPTIONS List---

--MAINTAINER--
[email protected]
--End MAINTAINER--

--CONFIGURE_ARGS--

--End CONFIGURE_ARGS--

--CONFIGURE_ENV--
PKG_CONFIG=pkgconf XDG_DATA_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work/.cache  
HOME=/wrkdirs/usr/ports/security/rustls-ffi/work 
TMPDIR="/wrkdirs/usr/ports/security/rustls-ffi/work" 
PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/security/rustls-ffi/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 SHELL=/bin/sh CONFIG_SHELL=/bin/sh
--End CONFIGURE_ENV--

--MAKE_ENV--
XDG_DATA_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/security/rustls-ffi/work/.cache  
HOME=/wrkdirs/usr/ports/security/rustls-ffi/work 
TMPDIR="/wrkdirs/usr/ports/security/rustls-ffi/work" 
PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/security/rustls-ffi/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 MK_DEBUG_FILES=no MK_KERNEL_SYMBOLS=no SHELL=/bin/sh NO_LINT=YES 
PREFIX=/usr/local  LOCALBASE=/usr/local  CC="cc" CFLAGS="-O2 -pipe  
-fstack-protector-strong -fno-strict-aliasing "  CPP="cpp" CPPFLAGS=""  
LDFLAGS=" " LIBS=""  CXX="c++" CXXFLAGS="-O2 -pipe -fstack-protector-strong 
-fno-strict-aliasing  " BSD_INSTALL_PROGRAM="install  -s -m 555"  
BSD_INSTALL_LIB="install  -s -m 0644"  BSD_INSTALL_SCRIPT="install  -m 555" 
 BSD_INSTALL_DATA="install  -m 0644"  BSD_INSTALL_MAN="install  -m 444"
--End MAKE_ENV--

--PLIST_SUB--
OSREL=14.4 PREFIX=%D LOCALBASE=/usr/local  RESETPREFIX=/usr/local LIB32DIR=lib 
DOCSDIR="share/doc/rustls-ffi"  EXAMPLESDIR="share/examples/rustls-ffi"  
DATADIR="share/rustls-ffi"  WWWDIR="www/rustls-ffi"  ETCDIR="etc/rustls-ffi"
--End PLIST_SUB--

--SUB_LIST--
PREFIX=/usr/local LOCALBASE=/usr/local  DATADIR=/usr/local/share/rustls-ffi 
DOCSDIR=/usr/local/share/doc/rustls-ffi 
EXAMPLESDIR=/usr/local/share/examples/rustls-ffi  
WWWDIR=/usr/local/www/rustls-ffi ETCDIR=/usr/local/etc/rustls-ffi
--End SUB_LIST--

---Begin make.conf---
USE_PACKAGE_DEPENDS=yes
BATCH=yes
WRKDIRPREFIX=/wrkdirs
PORTSDIR=/usr/ports
PACKAGES=/packages
DISTDIR=/distfiles
PACKAGE_BUILDING=yes
PACKAGE_BUILDING_FLAVORS=yes
####  ####
# XXX: We really need this but cannot use it while 'make checksum' does not
# try the next mirror on checksum failure.  It currently retries the same
# failed mirror and then fails rather then trying another.  It *does*
# try the next if the size is mismatched though.
#MASTER_SITE_FREEBSD=yes
# Build ALLOW_MAKE_JOBS_PACKAGES with 3 jobs
MAKE_JOBS_NUMBER=3
#### Misc Poudriere ####
.include "/etc/make.conf.ports_env"
GID=0
UID=0
DISABLE_MAKE_JOBS=poudriere
---End make.conf---
--Resource limits--
cpu time               (seconds, -t)  unlimited
file size           (512-blocks, -f)  unlimited
data seg size           (kbytes, -d)  33554432
stack size              (kbytes, -s)  524288
core file size      (512-blocks, -c)  unlimited
max memory size         (kbytes, -m)  unlimited
locked memory           (kbytes, -l)  unlimited
max user processes              (-u)  89999
open files                      (-n)  8192
virtual mem size        (kbytes, -v)  unlimited
swap limit              (kbytes, -w)  unlimited
socket buffer size       (bytes, -b)  unlimited
pseudo-terminals                (-p)  unlimited
kqueues                         (-k)  unlimited
umtx shared locks               (-o)  unlimited
pipebuf                         (-y)  unlimited
--End resource limits--
=======================<phase: check-sanity   >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 ISCL MIT accepted by the user
===========================================================================
=======================<phase: pkg-depends    >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===>   rustls-ffi-0.15.5 depends on file: /usr/local/sbin/pkg - not found
===>   Installing existing package /packages/All/pkg-2.8.4.pkg
[144amd64-default-job-33] Installing pkg-2.8.4...
[144amd64-default-job-33] Extracting pkg-2.8.4: .......... done
===>   rustls-ffi-0.15.5 depends on file: /usr/local/sbin/pkg - found
===>   Returning to build of rustls-ffi-0.15.5
===========================================================================
=======================<phase: fetch-depends  >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===========================================================================
=======================<phase: fetch          >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 ISCL MIT accepted by the user
=> rust/crates/hickory-net-0.26.3.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/hickory-net/hickory-net-0.26.3.crate
rust/crates/hickory-net-0.26.3.crate                   139 kB   18 MBps    00s
=> rust/crates/hickory-proto-0.26.3.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/hickory-proto/hickory-proto-0.26.3.crate
rust/crates/hickory-proto-0.26.3.crate                 304 kB   37 MBps    00s
=> rust/crates/hickory-resolver-0.26.3.crate doesn't seem to exist in 
/portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/hickory-resolver/hickory-resolver-0.26.3.crate
rust/crates/hickory-resolver-0.26.3.crate              154 kB   31 MBps    00s
=> rust/crates/ipconfig-0.3.4.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/ipconfig/ipconfig-0.3.4.crate
rust/crates/ipconfig-0.3.4.crate                        24 kB   26 MBps    00s
=> rust/crates/prefix-trie-0.8.4.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/prefix-trie/prefix-trie-0.8.4.crate
rust/crates/prefix-trie-0.8.4.crate                     79 kB   23 MBps    00s
=> rust/crates/resolv-conf-0.7.6.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/resolv-conf/resolv-conf-0.7.6.crate
rust/crates/resolv-conf-0.7.6.crate                     17 kB   31 MBps    00s
=> rust/crates/rustls-0.23.46.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/rustls/rustls-0.23.46.crate
rust/crates/rustls-0.23.46.crate                       377 kB   46 MBps    00s
=> rust/crates/tokio-util-0.7.18.crate doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://static.crates.io/crates/tokio-util/tokio-util-0.7.18.crate
rust/crates/tokio-util-0.7.18.crate                    137 kB   30 MBps    00s
=> rustls-rustls-ffi-v0.15.5_GH0.tar.gz doesn't seem to exist in /portdistfiles.
=> Attempting to fetch 
https://codeload.github.com/rustls/rustls-ffi/tar.gz/v0.15.5
fetch: https://codeload.github.com/rustls/rustls-ffi/tar.gz/v0.15.5: size 
unknown
fetch: https://codeload.github.com/rustls/rustls-ffi/tar.gz/v0.15.5: size of 
remote file is not known
rustls-rustls-ffi-v0.15.5_GH0.tar.gz                   683 kB 5183 kBps    00s
===> Fetching all distfiles required by rustls-ffi-0.15.5 for building
===========================================================================
=======================<phase: checksum       >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 ISCL MIT accepted by the user
===> Fetching all distfiles required by rustls-ffi-0.15.5 for building
=> SHA256 Checksum OK for rust/crates/aho-corasick-1.1.4.crate.
=> SHA256 Checksum OK for rust/crates/alloc-no-stdlib-2.0.4.crate.
=> SHA256 Checksum OK for rust/crates/alloc-stdlib-0.2.4.crate.
=> SHA256 Checksum OK for rust/crates/async-trait-0.1.89.crate.
=> SHA256 Checksum OK for rust/crates/atomic-waker-1.1.2.crate.
=> SHA256 Checksum OK for rust/crates/autocfg-1.5.1.crate.
=> SHA256 Checksum OK for rust/crates/aws-lc-fips-sys-0.14.2.crate.
=> SHA256 Checksum OK for rust/crates/aws-lc-rs-1.18.1.crate.
=> SHA256 Checksum OK for rust/crates/aws-lc-sys-0.45.0.crate.
=> SHA256 Checksum OK for rust/crates/bindgen-0.72.1.crate.
=> SHA256 Checksum OK for rust/crates/bitflags-2.13.0.crate.
=> SHA256 Checksum OK for rust/crates/brotli-8.0.4.crate.
=> SHA256 Checksum OK for rust/crates/brotli-decompressor-5.0.3.crate.
=> SHA256 Checksum OK for rust/crates/bumpalo-3.20.3.crate.
=> SHA256 Checksum OK for rust/crates/bytes-1.12.0.crate.
=> SHA256 Checksum OK for rust/crates/cc-1.2.65.crate.
=> SHA256 Checksum OK for rust/crates/cexpr-0.6.0.crate.
<snip>
locations based on paths typically used by `openssl`.
' CARGO_PKG_HOMEPAGE='https://github.com/rustls/openssl-probe' 
CARGO_PKG_LICENSE='MIT OR Apache-2.0' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=openssl-probe CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/openssl-probe' 
CARGO_PKG_RUST_VERSION=1.60.0 CARGO_PKG_VERSION=0.2.1 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=1 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name openssl_probe --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/openssl-probe-0.2.1/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values())' -C metadata=cec8d6cf5965639e -C 
extra-filename=-9fe62d796562c7c8 --out-dir
 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
   Compiling subtle v2.6.1
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=subtle 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/subtle-2.6.1
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/subtle-2.6.1/Cargo.toml
 CARGO_PKG_AUTHORS='Isis Lovecruft <[email protected]>:Henry de 
Valence <[email protected]>' CARGO_PKG_DESCRIPTION='Pure-Rust traits and 
utilities for constant-time cryptographic implementations.' 
CARGO_PKG_HOMEPAGE='https://dalek.rs/' CARGO_PKG_LICENSE=BSD-3-Clause 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=subtle CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/dalek-cryptography/subtle' 
CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=2.6.1 CARGO_PKG_VERSION_MAJOR=2 
CARGO_PKG_VERSION_MINOR=6 CARGO_PKG_VERSION_PATCH=1 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name subtle
 --edition=2018 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/subtle-2.6.1/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("const-generics", "core_hint_black_box", "default", 
"i128", "nightly", "std"))' -C metadata=f946628066f5be62 -C 
extra-filename=-8fc63a41e3b56572 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
   Compiling once_cell v1.21.4
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=once_cell 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/once_cell-1.21.4
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/once_cell-1.21.4/Cargo.toml
 CARGO_PKG_AUTHORS='Aleksey Kladov <[email protected]>' 
CARGO_PKG_DESCRIPTION='Single assignment cells and lazy values.' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR Apache-2.0' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=once_cell CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/matklad/once_cell' 
CARGO_PKG_RUST_VERSION=1.65 CARGO_PKG_VERSION=1.21.4 CARGO_PKG_VERSION_MAJOR=1 
CARGO_PKG_VERSION_MINOR=21 CARGO_PKG_VERSION_PATCH=4 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name once_cell --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/carg
o-crates/once_cell-1.21.4/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type lib 
--emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="alloc"' --cfg 
'feature="race"' --cfg 'feature="std"' --check-cfg 'cfg(docsrs,test)' 
--check-cfg 'cfg(feature, values("alloc", "atomic-polyfill", 
"critical-section", "default", "parking_lot", "portable-atomic", "race", "std", 
"unstable"))' -C metadata=ab6d51ad07188113 -C extra-filename=-2008c090ba494027 
--out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=rustls 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-0.23.46
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-0.23.46/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Rustls is a modern TLS library 
written in Rust.' CARGO_PKG_HOMEPAGE='https://github.com/rustls/rustls' 
CARGO_PKG_LICENSE='Apache-2.0 OR ISC OR MIT' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=rustls CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls' 
CARGO_PKG_RUST_VERSION=1.71 CARGO_PKG_VERSION=0.23.46 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=23 CARGO_PKG_VERSION_PATCH=46 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/rustls-7807c59d51f192cb/out
 /usr/loc
al/bin/rustc --crate-name rustls --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-0.23.46/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --warn=unexpected_cfgs --check-cfg 
'cfg(bench)' --check-cfg 'cfg(coverage_nightly)' --check-cfg 'cfg(read_buf)' 
--check-cfg 'cfg(rustls_docsrs)' --cfg 'feature="aws-lc-rs"' --cfg 
'feature="aws_lc_rs"' --cfg 'feature="prefer-post-quantum"' --cfg 
'feature="std"' --cfg 'feature="tls12"' --check-cfg 'cfg(docsrs,test)' 
--check-cfg 'cfg(feature, values("aws-lc-rs", "aws_lc_rs", "brotli", 
"custom-provider", "default", "fips", "hashbrown", "log", "logging", 
"prefer-post-quantum", "read_buf", "ring", "rustversion", "std", "tls12", 
"zlib"))' -C metadata=292a7080b3a7a409 -C extra-filename=-7db52d1d3f9a44b3 
--out-dir /wrkdirs/usr/ports/security/rust
ls-ffi/work/target/x86_64-unknown-freebsd/release/deps --target 
x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern 
aws_lc_rs=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libaws_lc_rs-d04d40c90ca92257.rmeta
 --extern 
once_cell=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libonce_cell-2008c090ba494027.rmeta
 --extern 
pki_types=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls_pki_types-218f652198d34a2a.rmeta
 --extern 
webpki=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libwebpki-44bf4b0c11fc8369.rmeta
 --extern 
subtle=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libsubtle-8fc63a41e3b56572.rmeta
 -
-extern 
zeroize=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libzeroize-16abec2ec39b53f1.rmeta
 --cap-lints warn -Cmetadata=rustls-ffi -C linker=cc -L 
native=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out`
   Compiling rustls-native-certs v0.8.4
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=rustls_native_certs 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-native-certs-0.8.4
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-native-certs-0.8.4/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='rustls-native-certs allows rustls 
to use the platform native certificate store' 
CARGO_PKG_HOMEPAGE='https://github.com/rustls/rustls-native-certs' 
CARGO_PKG_LICENSE='Apache-2.0 OR ISC OR MIT' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=rustls-native-certs CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-native-certs' 
CARGO_PKG_RUST_VERSION=1.71 CARGO_PKG_VERSION=0.8.4 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=8 CARGO_PKG_VERSION_PATCH=4 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-na
me rustls_native_certs --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-native-certs-0.8.4/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --warn=unexpected_cfgs --check-cfg 
'cfg(rustls_native_certs_docsrs)' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values())' -C metadata=0f4d21105a313907 -C 
extra-filename=-de48ccc6d5caf45c --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern 
openssl_probe=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libopen
ssl_probe-9fe62d796562c7c8.rmeta --extern 
pki_types=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls_pki_types-218f652198d34a2a.rmeta
 --cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
     Running `CARGO=/usr/local/bin/cargo CARGO_CFG_FEATURE=default,std 
CARGO_CFG_PANIC=unwind CARGO_CFG_TARGET_ABI='' CARGO_CFG_TARGET_ARCH=x86_64 
CARGO_CFG_TARGET_ENDIAN=little CARGO_CFG_TARGET_ENV='' 
CARGO_CFG_TARGET_FAMILY=unix CARGO_CFG_TARGET_FEATURE=fxsr,sse,sse2 
CARGO_CFG_TARGET_HAS_ATOMIC=16,32,64,8,ptr 
CARGO_CFG_TARGET_HAS_ATOMIC_PRIMITIVE_ALIGNMENT=16,32,64,8,ptr 
CARGO_CFG_TARGET_OS=freebsd CARGO_CFG_TARGET_POINTER_WIDTH=64 
CARGO_CFG_TARGET_VENDOR=unknown CARGO_CFG_UNIX='' 
CARGO_ENCODED_RUSTFLAGS='-Clinker=cc' CARGO_FEATURE_DEFAULT=1 
CARGO_FEATURE_STD=1 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/libc-0.2.190
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/libc-0.2.190/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Raw FFI bindings to platform 
libraries like libc.' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR 
Apache-2.0' CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NA
ME=libc CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rust-lang/libc' 
CARGO_PKG_RUST_VERSION=1.65 CARGO_PKG_VERSION=0.2.190 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=190 CARGO_PKG_VERSION_PRE='' 
DEBUG=false HOST=x86_64-unknown-freebsd 
LD_LIBRARY_PATH='/wrkdirs/usr/ports/security/rustls-ffi/work/target/release:/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps:/usr/local/lib/rustlib/x86_64-unknown-freebsd/lib'
 NUM_JOBS=1 OPT_LEVEL=2 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/libc-3719bf2d276c1d26/out
 PROFILE=release RUSTC=/usr/local/bin/rustc RUSTDOC=/usr/local/bin/rustdoc 
TARGET=x86_64-unknown-freebsd 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/build/libc-454b449fa8bafef0/build-script-build`
[libc 0.2.190] cargo:rerun-if-changed=build.rs
[libc 0.2.190] cargo:rerun-if-env-changed=LIBC_BUILD_VERBOSE
[libc 0.2.190] cargo:rerun-if-env-changed=RUST_LIBC_UNSTABLE_FREEBSD_VERSION
[libc 0.2.190] cargo:rustc-check-cfg=cfg(libc_deny_warnings)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(emscripten_old_stat_abi)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(espidf_picolibc)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(espidf_time32)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd10)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd11)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd12)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd13)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd14)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(freebsd15)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(libc_elfv2)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(vxworks_lt_25_09)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(libc_pauthtest)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(gnu_file_offset_bits64)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(gnu_time_bits64)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(linux_time_bits64)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(musl_v1_2)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(musl32_time64)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(musl_redir_time64)
[libc 0.2.190] cargo:rustc-check-cfg=cfg(uclibc32_time64)
[libc 0.2.190] 
cargo:rustc-check-cfg=cfg(target_os,values("switch","aix","ohos","hurd","rtems","visionos","nuttx","cygwin","qurt","qnx","helenos"))
[libc 0.2.190] 
cargo:rustc-check-cfg=cfg(target_env,values("illumos","wasi","aix","ohos","nto71_iosock"))
[libc 0.2.190] 
cargo:rustc-check-cfg=cfg(target_arch,values("loongarch64","mips32r6","mips64r6","csky"))
[libc 0.2.190] cargo:rustc-cfg=freebsd12
   Compiling rustls-ffi v0.15.5 
(/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=build_script_build 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Rustls bindings for non-Rust 
languages' CARGO_PKG_HOMEPAGE='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_LICENSE='Apache-2.0 OR ISC OR MIT' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=rustls-ffi CARGO_PKG_README=../README-crates.io.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_RUST_VERSION=1.85 CARGO_PKG_VERSION=0.15.5 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=15 CARGO_PKG_VERSION_PATCH=5 CARGO_PKG_VERSION_PRE='' 
CARGO_PRIMARY_PACKAGE=1 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name build_script_build --edition=2021 
librustls/build.rs --error-format=json --json=diag
nostic-rendered-ansi,artifacts,future-incompat --crate-type bin 
--emit=dep-info,link -C embed-bitcode=no -C debug-assertions=off --cfg 
'feature="aws-lc-rs"' --cfg 'feature="capi"' --cfg 'feature="default"' --cfg 
'feature="prefer-post-quantum"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("aws-lc-rs", "capi", "cert_compression", "default", 
"fips", "no_log_capture", "prefer-post-quantum", "read_buf", "ring"))' -C 
metadata=eea31e3b456ad885 -C extra-filename=-8d72fecbe56eb6b1 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/build/rustls-ffi-8d72fecbe56eb6b1
 -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps`
   Compiling pastey v0.2.3
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=pastey 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/pastey-0.2.3
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/pastey-0.2.3/Cargo.toml
 CARGO_PKG_AUTHORS='Aditya Kumar <[email protected]>:David Tolnay 
<[email protected]>' CARGO_PKG_DESCRIPTION='Macros for all your token pasting 
needs. Successor of paste.' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR 
Apache-2.0' CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=pastey 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/as1100k/pastey' 
CARGO_PKG_RUST_VERSION=1.54 CARGO_PKG_VERSION=0.2.3 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=3 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name pastey --edition=2018 
/wrkdirs/usr/ports/security/rustls-ffi/work/r
ustls-ffi-0.15.5/cargo-crates/pastey-0.2.3/src/lib.rs --error-format=json 
--json=diagnostic-rendered-ansi,artifacts,future-incompat --crate-type 
proc-macro --emit=dep-info,link -C prefer-dynamic -C embed-bitcode=no 
--warn=unexpected_cfgs --check-cfg 'cfg(coverage_nightly)' -C 
debug-assertions=off --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values())' -C metadata=b36998811bb8da86 -C extra-filename=-ca026078b1e22193 
--out-dir /wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps -C 
strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern proc_macro --cap-lints warn`
   Compiling macro_rules_attribute-proc_macro v0.2.3
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CRATE_NAME=macro_rules_attribute_proc_macro 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-proc_macro-0.2.3
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-proc_macro-0.2.3/Cargo.toml
 CARGO_PKG_AUTHORS='Daniel Henry-Mantilla <[email protected]>' 
CARGO_PKG_DESCRIPTION='Use declarative macros as proc_macro attributes or 
derives' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='Apache-2.0 OR MIT OR Zlib' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=macro_rules_attribute-proc_macro 
CARGO_PKG_README='' 
CARGO_PKG_REPOSITORY='https://github.com/danielhenrymantilla/macro_rules_attribute-rs'
 CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=0.2.3 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=3 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work
/target/release/deps /usr/local/bin/rustc --crate-name 
macro_rules_attribute_proc_macro --edition=2018 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-proc_macro-0.2.3/mod.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type proc-macro --emit=dep-info,link -C prefer-dynamic -C 
embed-bitcode=no -C debug-assertions=off --check-cfg 'cfg(docsrs,test)' 
--check-cfg 'cfg(feature, values("verbose-expansions"))' -C 
metadata=9ba04c06843d5ae0 -C extra-filename=-01f43cd2b9866130 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps -C 
strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern proc_macro --cap-lints warn`
warning: non-local `impl` definition, `impl` blocks should be written at the 
same level as their item
   --> 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-proc_macro-0.2.3/mod.rs:300:9
    |
297 | /     fn vec (self: Self)
298 | |       -> Vec<Self::Item>
    | |________________________- move the `impl` block outside of this method 
`vec`
299 |       {
300 |           impl<T : IntoIterator> CollectVec for T {}
    |           ^^^^^^^^^^^^^^^^^^^^^^^----------^^^^^^
    |                                  |
    |                                  `CollectVec` is not local
    |
    = note: an `impl` is never scoped, even when it is nested inside an item, 
as it may impact type checking outside of that item, which can be the case if 
neither the trait or the self type are at the same nesting level as the `impl`
    = note: `#[warn(non_local_definitions)]` on by default

warning: `macro_rules_attribute-proc_macro` (lib) generated 1 warning
   Compiling log v0.4.34
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=log 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/log-0.4.34
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/log-0.4.34/Cargo.toml
 CARGO_PKG_AUTHORS='The Rust Project Developers' CARGO_PKG_DESCRIPTION='A 
lightweight logging facade for Rust
' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR Apache-2.0' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=log CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rust-lang/log' 
CARGO_PKG_RUST_VERSION=1.71.0 CARGO_PKG_VERSION=0.4.34 
CARGO_PKG_VERSION_MAJOR=0 CARGO_PKG_VERSION_MINOR=4 CARGO_PKG_VERSION_PATCH=34 
CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-name log --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/log-0.4.34/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("alloc", "kv", "kv_serde", "kv_std", "kv_sval", 
"kv_unstable", "kv_unstable_serde", "kv_unstable_std", "kv_unstable_sval", 
"max_level_debug", "max_leve
l_error", "max_level_info", "max_level_off", "max_level_trace", 
"max_level_warn", "release_max_level_debug", "release_max_level_error", 
"release_max_level_info", "release_max_level_off", "release_max_level_trace", 
"release_max_level_warn", "serde", "serde_core", "std", "sval", "sval_ref", 
"value-bag"))' -C metadata=8f407ef62c2d7d45 -C extra-filename=-ac5db93411d74be2 
--out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
   Compiling rustls-platform-verifier v0.7.1
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CRATE_NAME=rustls_platform_verifier 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-platform-verifier-0.7.1
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-platform-verifier-0.7.1/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='rustls-platform-verifier supports 
verifying TLS certificates in rustls with the operating system verifier' 
CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR Apache-2.0' 
CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=rustls-platform-verifier 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-platform-verifier' 
CARGO_PKG_RUST_VERSION=1.85 CARGO_PKG_VERSION=0.7.1 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=7 CARGO_PKG_VERSION_PATCH=1 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
/usr/local/bin/rustc --crate-na
me rustls_platform_verifier --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/rustls-platform-verifier-0.7.1/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("android_logger", "base64", "cert-logging", "dbg", 
"docsrs", "ffi-testing", "jni", "once_cell"))' -C metadata=bee8097439e57c12 -C 
extra-filename=-2c25661a02946ee2 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern 
log=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-fre
ebsd/release/deps/liblog-ac5db93411d74be2.rmeta --extern 
rustls=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls-7db52d1d3f9a44b3.rmeta
 --extern 
rustls_native_certs=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls_native_certs-de48ccc6d5caf45c.rmeta
 --extern 
webpki=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libwebpki-44bf4b0c11fc8369.rmeta
 --cap-lints warn -Cmetadata=rustls-ffi -C linker=cc -L 
native=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out`
   Compiling macro_rules_attribute v0.2.3
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=macro_rules_attribute 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-0.2.3
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-0.2.3/Cargo.toml
 CARGO_PKG_AUTHORS='Daniel Henry-Mantilla <[email protected]>' 
CARGO_PKG_DESCRIPTION='Use declarative macros in attribute or derive position' 
CARGO_PKG_HOMEPAGE='https://crates.io/crates/macro_rules_attribute' 
CARGO_PKG_LICENSE='Apache-2.0 OR MIT OR Zlib' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=macro_rules_attribute CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/danielhenrymantilla/macro_rules_attribute-rs'
 CARGO_PKG_RUST_VERSION='' CARGO_PKG_VERSION=0.2.3 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=3 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi
/work/target/release/deps /usr/local/bin/rustc --crate-name 
macro_rules_attribute --edition=2018 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-0.2.3/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --cfg 'feature="default"' --check-cfg 
'cfg(docsrs,test)' --check-cfg 'cfg(feature, values("better-docs", "default", 
"verbose-expansions"))' -C metadata=ba2106ed158c83b1 -C 
extra-filename=-bf3cbc9ce41a05de --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern macro_rules_attribute_proc_macro=/wrkdirs/us
r/ports/security/rustls-ffi/work/target/release/deps/libmacro_rules_attribute_proc_macro-01f43cd2b9866130.so
 --extern 
pastey=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps/libpastey-ca026078b1e22193.so
 --cap-lints warn -Cmetadata=rustls-ffi -C linker=cc`
     Running `CARGO=/usr/local/bin/cargo 
CARGO_CFG_FEATURE=aws-lc-rs,capi,default,prefer-post-quantum 
CARGO_CFG_PANIC=unwind CARGO_CFG_TARGET_ABI='' CARGO_CFG_TARGET_ARCH=x86_64 
CARGO_CFG_TARGET_ENDIAN=little CARGO_CFG_TARGET_ENV='' 
CARGO_CFG_TARGET_FAMILY=unix CARGO_CFG_TARGET_FEATURE=fxsr,sse,sse2 
CARGO_CFG_TARGET_HAS_ATOMIC=16,32,64,8,ptr 
CARGO_CFG_TARGET_HAS_ATOMIC_PRIMITIVE_ALIGNMENT=16,32,64,8,ptr 
CARGO_CFG_TARGET_OS=freebsd CARGO_CFG_TARGET_POINTER_WIDTH=64 
CARGO_CFG_TARGET_VENDOR=unknown CARGO_CFG_UNIX='' 
CARGO_ENCODED_RUSTFLAGS='-Clinker=cc' CARGO_FEATURE_AWS_LC_RS=1 
CARGO_FEATURE_CAPI=1 CARGO_FEATURE_DEFAULT=1 
CARGO_FEATURE_PREFER_POST_QUANTUM=1 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls
 CARGO_MANIFEST_LINKS=rustls_ffi 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Rustls bindings for non-Rust 
languages' CARGO_PKG_HOMEP
AGE='https://github.com/rustls/rustls-ffi' CARGO_PKG_LICENSE='Apache-2.0 OR ISC 
OR MIT' CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=rustls-ffi 
CARGO_PKG_README=../README-crates.io.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_RUST_VERSION=1.85 CARGO_PKG_VERSION=0.15.5 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=15 CARGO_PKG_VERSION_PATCH=5 CARGO_PKG_VERSION_PRE='' 
DEBUG=false HOST=x86_64-unknown-freebsd 
LD_LIBRARY_PATH='/wrkdirs/usr/ports/security/rustls-ffi/work/target/release:/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps:/usr/local/lib/rustlib/x86_64-unknown-freebsd/lib'
 NUM_JOBS=1 OPT_LEVEL=2 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/rustls-ffi-e867f76ff355bf34/out
 PROFILE=release RUSTC=/usr/local/bin/rustc RUSTDOC=/usr/local/bin/rustdoc 
TARGET=x86_64-unknown-freebsd 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/build/rustls-ffi-8d72fecbe56eb6b1/build-script-build`
[rustls-ffi 0.15.5] 
cargo:include=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/rustls-ffi-e867f76ff355bf34/out/include
[rustls-ffi 0.15.5] cargo:rerun-if-env-changed=CARGO_PKG_VERSION
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=libc 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/libc-0.2.190
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/libc-0.2.190/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Raw FFI bindings to platform 
libraries like libc.' CARGO_PKG_HOMEPAGE='' CARGO_PKG_LICENSE='MIT OR 
Apache-2.0' CARGO_PKG_LICENSE_FILE='' CARGO_PKG_NAME=libc 
CARGO_PKG_README=README.md 
CARGO_PKG_REPOSITORY='https://github.com/rust-lang/libc' 
CARGO_PKG_RUST_VERSION=1.65 CARGO_PKG_VERSION=0.2.190 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=2 CARGO_PKG_VERSION_PATCH=190 CARGO_PKG_VERSION_PRE='' 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/libc-3719bf2d276c1d26/out
 /usr/local/bin/rustc --crate-name libc --edition=2021 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/libc-0.2.190/src/lib.rs
 --error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type lib --emit=dep-info,metadata,link -C opt-level=2 -C panic=abort -C 
linker-plugin-lto -C codegen-units=1 --allow=unused_qualifications 
'--warn=clippy::unnecessary_semicolon' '--allow=clippy::unnecessary_cast' 
'--warn=clippy::ptr_as_ptr' '--allow=clippy::non_minimal_cfg' 
'--allow=clippy::missing_safety_doc' '--warn=clippy::map_unwrap_or' 
'--warn=clippy::manual_assert' '--allow=clippy::identity_op' 
'--warn=clippy::explicit_iter_loop' --cfg 'feature="default"' --cfg 
'feature="std"' --check-cfg 'cfg(docsrs,test)' --check-cfg 'cfg(feature, 
values("align", "const-extern-fn", "default", "extra_traits", 
"rustc-dep-of-std", "rustc-std-workspace-core", "std", "use_std"))' -C 
metadata=5a417cb2bcb3b0e2 -C extra-filename=-afc2e96e13fb2084 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86
_64-unknown-freebsd/release/deps --target x86_64-unknown-freebsd -C 
strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--cap-lints warn -Cmetadata=rustls-ffi -C linker=cc --cfg freebsd12 --check-cfg 
'cfg(libc_deny_warnings)' --check-cfg 'cfg(emscripten_old_stat_abi)' 
--check-cfg 'cfg(espidf_picolibc)' --check-cfg 'cfg(espidf_time32)' --check-cfg 
'cfg(freebsd10)' --check-cfg 'cfg(freebsd11)' --check-cfg 'cfg(freebsd12)' 
--check-cfg 'cfg(freebsd13)' --check-cfg 'cfg(freebsd14)' --check-cfg 
'cfg(freebsd15)' --check-cfg 'cfg(libc_elfv2)' --check-cfg 
'cfg(vxworks_lt_25_09)' --check-cfg 'cfg(libc_pauthtest)' --check-cfg 
'cfg(gnu_file_offset_bits64)' --check-cfg 'cfg(gnu_time_bits64)' --check-cfg 
'cfg(linux_time_bits64)' --check-cfg 'cfg(musl_v1_2)' --check-cfg 
'cfg(musl32_time64)' --check-cfg 'cfg(musl_redir_time64)' --check-cfg 
'cfg(uclibc3
2_time64)' --check-cfg 
'cfg(target_os,values("switch","aix","ohos","hurd","rtems","visionos","nuttx","cygwin","qurt","qnx","helenos"))'
 --check-cfg 
'cfg(target_env,values("illumos","wasi","aix","ohos","nto71_iosock"))' 
--check-cfg 
'cfg(target_arch,values("loongarch64","mips32r6","mips64r6","csky"))'`
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=rustls 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Rustls bindings for non-Rust 
languages' CARGO_PKG_HOMEPAGE='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_LICENSE='Apache-2.0 OR ISC OR MIT' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=rustls-ffi CARGO_PKG_README=../README-crates.io.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_RUST_VERSION=1.85 CARGO_PKG_VERSION=0.15.5 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=15 CARGO_PKG_VERSION_PATCH=5 CARGO_PKG_VERSION_PRE='' 
CARGO_PRIMARY_PACKAGE=1 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/rustls-ffi-e867f76ff355bf34/out
 /u
sr/local/bin/rustc --crate-name rustls --edition=2021 librustls/src/lib.rs 
--error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type staticlib --crate-type cdylib --emit=dep-info,link -C opt-level=2 
-C panic=abort -C lto -C codegen-units=1 --cfg 'feature="aws-lc-rs"' --cfg 
'feature="capi"' --cfg 'feature="default"' --cfg 
'feature="prefer-post-quantum"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("aws-lc-rs", "capi", "cert_compression", "default", 
"fips", "no_log_capture", "prefer-post-quantum", "read_buf", "ring"))' -C 
metadata=a62edcde1feea470 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern libc=/wrkdirs/usr/ports/security/rustls-ffi/work/ta
rget/x86_64-unknown-freebsd/release/deps/liblibc-afc2e96e13fb2084.rlib --extern 
log=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/liblog-ac5db93411d74be2.rlib
 --extern 
macro_rules_attribute=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libmacro_rules_attribute-bf3cbc9ce41a05de.rlib
 --extern 
rustls=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls-7db52d1d3f9a44b3.rlib
 --extern 
rustls_platform_verifier=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls_platform_verifier-2c25661a02946ee2.rlib
 --extern 
webpki=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libwebpki-44bf4b0c11fc8369.rlib
 -C link-arg=-Wl,-soname,librustls.so.0.15.5 -Cmetadata=rustls-ffi --cfg 
cargo_c --print native-static-libs -C linker=cc -L 
native=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x8
6_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out`
note: link against the following native artifacts when linking against this 
static library. The order and any duplication can be significant on some 
platforms

    Finished `release` profile [optimized] target(s) in 3m 24s
    Building pkg-config files
  Populating uninstalled header directory
note: 
PKG_CONFIG_PATH="/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release"
===========================================================================
=======================<phase: run-depends    >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===========================================================================
=======================<phase: stage          >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  Staging for rustls-ffi-0.15.5
===>   Generating temporary packing list
       Fresh jobserver v0.1.34
warning: direct cast of function item into an integer
   --> 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/jobserver-0.1.34/src/unix.rs:389:48
    |
389 |             new.sa_sigaction = sigusr1_handler as usize;
    |                                                ^^^^^^^^
    |
    = note: `#[warn(function_casts_as_integer)]` on by default
help: first cast to a pointer `as *const ()`
    |
389 |             new.sa_sigaction = sigusr1_handler as *const () as usize;
    |                                                ++++++++++++

warning: `jobserver` (lib) generated 1 warning
       Fresh shlex v2.0.1
       Fresh find-msvc-tools v0.1.9
       Fresh cc v1.2.65
warning: use of deprecated method 
`std::sync::atomic::Atomic::<u32>::fetch_update`: renamed to `try_update` for 
consistency
   --> 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/cc-1.2.65/src/parallel/job_token.rs:248:22
    |
248 |                     .fetch_update(AcqRel, Acquire, |tokens| 
tokens.checked_sub(1));
    |                      ^^^^^^^^^^^^
    |
note: the lint level is defined here
   --> 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/cc-1.2.65/src/lib.rs:238:9
    |
238 | #![deny(warnings)]
    |         ^^^^^^^^
    = note: `#[warn(deprecated)]` implied by `#[warn(warnings)]`
help: replace the use of the deprecated method
    |
248 -                     .fetch_update(AcqRel, Acquire, |tokens| 
tokens.checked_sub(1));
248 +                     .try_update(AcqRel, Acquire, |tokens| 
tokens.checked_sub(1));
    |

warning: `cc` (lib) generated 1 warning
       Fresh cmake v0.1.58
       Fresh pkg-config v0.3.34
       Fresh fs_extra v1.3.0
       Fresh dunce v1.0.5
warning: [email protected]: Environment Variable found 
'CARGO_ENCODED_RUSTFLAGS': '-Clinker=cc'
warning: [email protected]: Emitting configuration: cargo:rustc-cfg=universal
warning: [email protected]: Building with: CC
warning: [email protected]: Symbol Prefix: Some("aws_lc_0_45_0")
warning: [email protected]: Target platform: 'x86_64-unknown-freebsd'
warning: [email protected]: Environment Variable found 'CFLAGS': '-O2 -pipe  
-fstack-protector-strong -fno-strict-aliasing '
warning: [email protected]: Setting CFLAGS_x86_64_unknown_freebsd: -O2 -pipe  
-fstack-protector-strong -fno-strict-aliasing
warning: [email protected]: Compilation of 'c11.c' succeeded - 
Ok(["/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out/out-c11/7dfda64fdf5a526c-c11.o"]).
warning: [email protected]: Environment Variable found 'CC': 'cc'
warning: [email protected]: Setting CC_x86_64_unknown_freebsd: cc
warning: [email protected]: Environment Variable found 'CXX': 'c++'
warning: [email protected]: Setting CXX_x86_64_unknown_freebsd: c++
warning: [email protected]: Compilation of 'stdalign_check.c' succeeded - 
Ok(["/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out/out-stdalign_check/7dfda64fdf5a526c-stdalign_check.o"]).
warning: [email protected]: Compilation of 'builtin_swap_check.c' succeeded - 
Ok(["/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out/out-builtin_swap_check/7dfda64fdf5a526c-builtin_swap_check.o"]).
       Fresh zeroize v1.8.2
       Fresh rustls-pki-types v1.14.1
       Fresh aws-lc-sys v0.45.0
       Fresh aws-lc-rs v1.18.1
       Fresh untrusted v0.9.0
       Fresh rustls-webpki v0.103.15
       Fresh openssl-probe v0.2.1
       Fresh subtle v2.6.1
       Fresh once_cell v1.21.4
       Fresh rustls v0.23.46
       Fresh rustls-native-certs v0.8.4
       Fresh pastey v0.2.3
       Fresh macro_rules_attribute-proc_macro v0.2.3
warning: non-local `impl` definition, `impl` blocks should be written at the 
same level as their item
   --> 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/cargo-crates/macro_rules_attribute-proc_macro-0.2.3/mod.rs:300:9
    |
297 | /     fn vec (self: Self)
298 | |       -> Vec<Self::Item>
    | |________________________- move the `impl` block outside of this method 
`vec`
299 |       {
300 |           impl<T : IntoIterator> CollectVec for T {}
    |           ^^^^^^^^^^^^^^^^^^^^^^^----------^^^^^^
    |                                  |
    |                                  `CollectVec` is not local
    |
    = note: an `impl` is never scoped, even when it is nested inside an item, 
as it may impact type checking outside of that item, which can be the case if 
neither the trait or the self type are at the same nesting level as the `impl`
    = note: `#[warn(non_local_definitions)]` on by default

warning: `macro_rules_attribute-proc_macro` (lib) generated 1 warning
       Fresh log v0.4.34
       Fresh rustls-platform-verifier v0.7.1
       Fresh macro_rules_attribute v0.2.3
       Fresh libc v0.2.190
       Dirty rustls-ffi v0.15.5 
(/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls): 
forced
   Compiling rustls-ffi v0.15.5 
(/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls)
     Running `CARGO=/usr/local/bin/cargo CARGO_CRATE_NAME=rustls 
CARGO_MANIFEST_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls
 
CARGO_MANIFEST_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls/Cargo.toml
 CARGO_PKG_AUTHORS='' CARGO_PKG_DESCRIPTION='Rustls bindings for non-Rust 
languages' CARGO_PKG_HOMEPAGE='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_LICENSE='Apache-2.0 OR ISC OR MIT' CARGO_PKG_LICENSE_FILE='' 
CARGO_PKG_NAME=rustls-ffi CARGO_PKG_README=../README-crates.io.md 
CARGO_PKG_REPOSITORY='https://github.com/rustls/rustls-ffi' 
CARGO_PKG_RUST_VERSION=1.85 CARGO_PKG_VERSION=0.15.5 CARGO_PKG_VERSION_MAJOR=0 
CARGO_PKG_VERSION_MINOR=15 CARGO_PKG_VERSION_PATCH=5 CARGO_PKG_VERSION_PRE='' 
CARGO_PRIMARY_PACKAGE=1 
LD_LIBRARY_PATH=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
OUT_DIR=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/build/rustls-ffi-e867f76ff355bf34/out
 /u
sr/local/bin/rustc --crate-name rustls --edition=2021 librustls/src/lib.rs 
--error-format=json --json=diagnostic-rendered-ansi,artifacts,future-incompat 
--crate-type staticlib --crate-type cdylib --emit=dep-info,link -C opt-level=2 
-C panic=abort -C lto -C codegen-units=1 --cfg 'feature="aws-lc-rs"' --cfg 
'feature="capi"' --cfg 'feature="default"' --cfg 
'feature="prefer-post-quantum"' --check-cfg 'cfg(docsrs,test)' --check-cfg 
'cfg(feature, values("aws-lc-rs", "capi", "cert_compression", "default", 
"fips", "no_log_capture", "prefer-post-quantum", "read_buf", "ring"))' -C 
metadata=a62edcde1feea470 --out-dir 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 --target x86_64-unknown-freebsd -C strip=symbols -L 
dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps
 -L dependency=/wrkdirs/usr/ports/security/rustls-ffi/work/target/release/deps 
--extern libc=/wrkdirs/usr/ports/security/rustls-ffi/work/ta
rget/x86_64-unknown-freebsd/release/deps/liblibc-afc2e96e13fb2084.rlib --extern 
log=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/liblog-ac5db93411d74be2.rlib
 --extern 
macro_rules_attribute=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libmacro_rules_attribute-bf3cbc9ce41a05de.rlib
 --extern 
rustls=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls-7db52d1d3f9a44b3.rlib
 --extern 
rustls_platform_verifier=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/librustls_platform_verifier-2c25661a02946ee2.rlib
 --extern 
webpki=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/deps/libwebpki-44bf4b0c11fc8369.rlib
 -C link-arg=-Wl,-soname,librustls.so.0.15.5 -Cmetadata=rustls-ffi --cfg 
cargo_c --print native-static-libs -C linker=cc -L 
native=/wrkdirs/usr/ports/security/rustls-ffi/work/target/x8
6_64-unknown-freebsd/release/build/aws-lc-sys-f40d70a5fc4010a0/out`
note: link against the following native artifacts when linking against this 
static library. The order and any duplication can be significant on some 
platforms

    Finished `release` profile [optimized] target(s) in 18.64s
    Building pkg-config files
  Populating uninstalled header directory
note: 
PKG_CONFIG_PATH="/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release"
  Installing pkg-config file
     Copying 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/rustls.pc
 to 
/wrkdirs/usr/ports/security/rustls-ffi/work/stage/usr/local/libdata/pkgconfig/rustls.pc
  Installing header file
     Copying 
/wrkdirs/usr/ports/security/rustls-ffi/work/rustls-ffi-0.15.5/librustls/src/rustls.h
 to /wrkdirs/usr/ports/security/rustls-ffi/work/stage/usr/local/include/rustls.h
  Installing static library
     Copying 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/librustls.a
 to /wrkdirs/usr/ports/security/rustls-ffi/work/stage/usr/local/lib/librustls.a
  Installing shared library
     Copying 
/wrkdirs/usr/ports/security/rustls-ffi/work/target/x86_64-unknown-freebsd/release/librustls.so
 to 
/wrkdirs/usr/ports/security/rustls-ffi/work/stage/usr/local/lib/librustls.so.0.15.5
====> Compressing man pages (compress-man)
===========================================================================
=======================<phase: package        >============================
===== env: 'PKG_NOTES=build_timestamp ports_top_git_hash 
ports_top_checkout_unclean port_git_hash port_checkout_unclean built_by' 
'PKG_NOTE_build_timestamp=2026-10-20T10:55:35+0000' 
'PKG_NOTE_ports_top_git_hash=ce97aa4dd1d9326775655b810ef384f38f78f0e5' 
'PKG_NOTE_ports_top_checkout_unclean=no' 
'PKG_NOTE_port_git_hash=08f51f9b6492b69c07ea2e068083214eaccda34e' 
'PKG_NOTE_port_checkout_unclean=no' 
'PKG_NOTE_built_by=poudriere-git-3.4.8-3-gd92fb7c0' NO_DEPENDS=yes USER=root 
UID=0 GID=0
===>  Building packages for rustls-ffi-0.15.5
===>   Building rustls-ffi-0.15.5
pkg-static: Unable to access file 
/wrkdirs/usr/ports/security/rustls-ffi/work/stage/usr/local/lib/librustls.so.0.15.4:No
 such file or directory
*** Error code 1

Stop.
make: stopped making "package" in /usr/ports/security/rustls-ffi

Reply via email to